emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/popper 86978d34bc 002/102: Cleaning up as preparation f


From: ELPA Syncer
Subject: [elpa] externals/popper 86978d34bc 002/102: Cleaning up as preparation for MELPA.
Date: Fri, 8 Sep 2023 15:58:49 -0400 (EDT)

branch: externals/popper
commit 86978d34bcd5108aa1a068961fb1ba743215ac5d
Author: Karthik Chikmagalur <karthikchikmagalur@gmail.com>
Commit: Karthik Chikmagalur <karthikchikmagalur@gmail.com>

    Cleaning up as preparation for MELPA.
---
 README.org                      |   4 ++--
 images/popper-cycle.gif         | Bin 0 -> 140942 bytes
 images/popper-demote.gif        | Bin 0 -> 336244 bytes
 images/popper-toggle-all.gif    | Bin 0 -> 86636 bytes
 images/popper-toggle-latest.gif | Bin 0 -> 104973 bytes
 popper.el                       |  23 ++++++++++++-----------
 6 files changed, 14 insertions(+), 13 deletions(-)

diff --git a/README.org b/README.org
index 0256dcfd1f..00e086afae 100644
--- a/README.org
+++ b/README.org
@@ -1,6 +1,6 @@
-#+title: Popper
+#+title: Popper.el
 
-A minor-mode to help with the Emacs window flood. Designate any buffer to 
"popup" status, and it will stay out of your way. Disimss or summon it easily 
with one key. Useful for many things, including toggling REPLS, documentation, 
compilation or shell output, etc.
+A minor-mode to help with the Emacs window flood. Designate any buffer to 
"popup" status, and it will stay out of your way. Disimss or summon it easily 
with one key. Useful for many things, including toggling display of REPLs, 
documentation, compilation or shell output, etc.
 
 popper can place your popups for you, but it Works best in conjunction
 with some system to handle window creation and placement, like =shackle.el=.
diff --git a/images/popper-cycle.gif b/images/popper-cycle.gif
new file mode 100755
index 0000000000..bb226ee0b7
Binary files /dev/null and b/images/popper-cycle.gif differ
diff --git a/images/popper-demote.gif b/images/popper-demote.gif
new file mode 100755
index 0000000000..48f28fc7f8
Binary files /dev/null and b/images/popper-demote.gif differ
diff --git a/images/popper-toggle-all.gif b/images/popper-toggle-all.gif
new file mode 100755
index 0000000000..f883312155
Binary files /dev/null and b/images/popper-toggle-all.gif differ
diff --git a/images/popper-toggle-latest.gif b/images/popper-toggle-latest.gif
new file mode 100755
index 0000000000..773af7b948
Binary files /dev/null and b/images/popper-toggle-latest.gif differ
diff --git a/popper.el b/popper.el
index a4a4fd9254..3ef54a5f41 100644
--- a/popper.el
+++ b/popper.el
@@ -1,4 +1,4 @@
 ;;; popper.el --- Summon and dismiss buffers easily. -*- lexical-binding: t -*-
 *-
 
 ;; Copyright (C) 2021  Karthik Chikmagalur
 
@@ -153,9 +153,9 @@ Action Alists\") for details on the alist."
       (member (buffer-local-value 'major-mode buf) popper-reference-modes)))
 
 (defun popper-display-control-p (buf &optional _act)
-  "Predicate to test if display of buffer BUF needs to be handled
-by popup-buffer. This is intended to be used in
-`display-buffer-alist'."
+  "Predicate to test if display of buffer BUF needs to be handled by popper.
+
+This is intended to be used in `display-buffer-alist'."
   (let ((buffer (if (bufferp buf) buf (get-buffer buf))))
     (pcase popper-display-control
       ('user
@@ -165,8 +165,8 @@ by popup-buffer. This is intended to be used in
             (memq popper-popup-status '(popup user-popup)))))))
 
 (defun popper-find-popups (test-buffer-list)
-  "Return an alist of (window . buffer) corresponding to
-popper in the list of buffers TEST-BUFFER-LIST."
+  "Return an alist of (window . buffer) corresponding to popups
+in the list of buffers TEST-BUFFER-LIST."
   (let* (open-popups)
     (dolist (b test-buffer-list open-popups)
       (let ((popup-status (buffer-local-value 'popper-popup-status b)))
@@ -265,13 +265,14 @@ the screen by `display-buffer' will not all be displayed."
 (defun popper-toggle-latest (&optional arg)
   "Toggle visibility of the last opened popup window.
 
-With prefix ARG C-u, toggle visibility of the next popup windows
+With prefix ARG \\[universal-argument], toggle visibility of the next popup 
windows
 while keeping the current one (FIXME: This behavior can be
 inconsistent.)
 
-With a double prefix ARG C-u C-u, toggle all popup-windows. Note
-that only one buffer can be show in one 'slot', so it will
-display as many windows as it can."
+With a double prefix ARG \\[universal-argument]
+\\[universal-argument], toggle all popup-windows. Note that only
+one buffer can be show in one 'slot', so it will display as many
+windows as it can."
   (interactive "p")
   (if popper-open-popup-alist
       (pcase arg
@@ -370,4 +371,4 @@ details on how to designate buffer types as popups."
                 display-buffer-alist))))
 
 (provide 'popper)
-;;; popper ends here
+;;; popper.el ends here
@@ -1,4 +1,4 @@
-;;; popper.el --- Summon and dismiss buffers easily. -*- lexical-binding: t -*-
+;;; popper.el --- Summon and dismiss buffers as popups -*- lexical-binding: t 
-*-
 
 ;; Copyright (C) 2021  Karthik Chikmagalur



reply via email to

[Prev in Thread] Current Thread [Next in Thread]